| Title: | Introduction to Some Combinatorial Relations |
|---|---|
| Description: | Determining the value of Stirling numbers of 1st kind and 2nd kind,references: Bóna,Miklós(2017,ISBN 9789813148840). |
| Authors: | Anik Paul [aut, cre] |
| Maintainer: | Anik Paul <[email protected]> |
| License: | GPL-3 |
| Version: | 0.1.0 |
| Built: | 2026-06-03 10:32:40 UTC |
| Source: | https://github.com/cran/combinatorics |
Determining the Stirling number of second kind.
Stirling2(n, k)Stirling2(n, k)
n |
the first parameter representing the number of elements in the set total. |
k |
the second parameter representing the number of groups to be formed. |
Stirling numbers of second kind is a very useful term used in combinatorics denoting the number of all possible groups of size k from a set of size n.
Stirling2: the determined value of Stirling numbers of second kind.
Anik Paul
Bóna,Miklós(2017,ISBN 9789813148840).
Stirling2(3,2)Stirling2(3,2)