Welcome to ClientVPS Mirrors

Help for package combinatorics
Type: Package
Title: Introduction to Some Combinatorial Relations
Version: 0.1.0
Maintainer: Anik Paul <paulanik2019@gmail.com>
Description: Determining the value of Stirling numbers of 1st kind and 2nd kind,references: Bóna,Miklós(2017,ISBN 9789813148840).
License: GPL-3
Encoding: UTF-8
RoxygenNote: 7.2.1
Suggests: knitr, rmarkdown, testthat (≥ 3.0.0)
VignetteBuilder: knitr
Config/testthat/edition: 3
NeedsCompilation: no
Packaged: 2022-11-01 10:14:39 UTC; ANIK
Author: Anik Paul [aut, cre]
Repository: CRAN
Date/Publication: 2022-11-01 15:20:26 UTC

Prints the value of Stirling numbers of second kind

Description

Determining the Stirling number of second kind.

Usage

Stirling2(n, k)

Arguments

n

the first parameter representing the number of elements in the set total.

k

the second parameter representing the number of groups to be formed.

Details

Stirling numbers of second kind is a very useful term used in combinatorics denoting the number of all possible groups of size k from a set of size n.

Value

Stirling2: the determined value of Stirling numbers of second kind.

Author(s)

Anik Paul

References

Bóna,Miklós(2017,ISBN 9789813148840).

Examples

Stirling2(3,2)

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.